==> es7s-3.45.0.dev0-py3-none-any.whl: es7s/cli/print/colors/rgb.py <==
# ------------------------------------------------------------------------------
#  es7s/core
#  (c) 2023 A. Shavykin <0.delameter@gmail.com>
# ------------------------------------------------------------------------------
from __future__ import annotations

from collections.abc import Iterable

import pytermor as pt
from es7s.cli._base import CliCommand
from es7s.cli._base_opts_params import IntRange
from es7s.cli._decorators import _catch_and_log_and_exit, cli_command, cli_option
from es7s.shared import get_stdout, init_io, init_logger


@cli_command(name=__file__, cls=CliCommand, short_help="rgb spectre")
@cli_option("-i", "--invert", default=False, is_flag=True, help="Use inverted colors.")
@cli_option(
    "-w",
    "--width",
    default=77,
    type=IntRange(_min=3, max_open=True),
    help="Gradient width, in characters.",
)
@_catch_and_log_and_exit
def invoker(invert: bool, width: int):
    """
    Display RGB color gradient.
    """

    def inv(*vv: int) -> Iterable[int]:
        yield from [255 - v for v in vv]

    s = " ·" * (width // 2 + 1)
    colors = []

    stdout = get_stdout()
    stdout.echo(pt.SeqIndex.BOLD)

    for c in range(width):
        r = 255 - (c * 255 // (width - 1))
        g = c * 510 // (width - 1)
        b = c * 255 // (width - 1)
        if g > 255:
            g = 510 - g
        if invert:
            r, g, b = inv(r, g, b)
        colors.append((r, g, b, s[c]))

    for col in [*colors]:
        if not col:
            stdout.echo()
            continue
        r, g, b, c = col
        stdout.echo_rendered(
            pt.Fragment(
                c,
                pt.Style(
                    # fg=pt.rgb_to_hex(pt.RGB(max(0, r - 128), max(0, g - 128), max(0, b - 128))),
                    fg=pt.rgb_to_hex(pt.RGB(255 - r, 255 - g, 255 - b)),
                    bg=pt.rgb_to_hex(pt.RGB(r, g, b)),
                ),
            ),
            nl=False,
        )
    stdout.echo(pt.SeqIndex.BOLD_DIM_OFF)
    stdout.echo()

==> es7s-3.48.0.dev0-py3-none-any.whl: es7s/cli/print/colors/rgb.py <==
# ------------------------------------------------------------------------------
#  es7s/core
#  (c) 2023 A. Shavykin <0.delameter@gmail.com>
# ------------------------------------------------------------------------------
from __future__ import annotations

from collections.abc import Iterable

import pytermor as pt
from ..._base import CliCommand
from ..._base_opts_params import IntRange
from ..._decorators import _catch_and_log_and_exit, cli_command, cli_option
from es7s.shared import get_stdout, init_io, init_logger


@cli_command(name=__file__, cls=CliCommand, short_help="rgb spectre")
@cli_option("-i", "--invert", default=False, is_flag=True, help="Use inverted colors.")
@cli_option(
    "-w",
    "--width",
    default=77,
    type=IntRange(_min=3, max_open=True),
    help="Gradient width, in characters.",
)
@_catch_and_log_and_exit
def invoker(invert: bool, width: int):
    """
    Display RGB color gradient.
    """

    def inv(*vv: int) -> Iterable[int]:
        yield from [255 - v for v in vv]

    s = " ·" * (width // 2 + 1)
    colors = []

    stdout = get_stdout()
    stdout.echo(pt.SeqIndex.BOLD)

    for c in range(width):
        r = 255 - (c * 255 // (width - 1))
        g = c * 510 // (width - 1)
        b = c * 255 // (width - 1)
        if g > 255:
            g = 510 - g
        if invert:
            r, g, b = inv(r, g, b)
        colors.append((r, g, b, s[c]))

    for col in [*colors]:
        if not col:
            stdout.echo()
            continue
        r, g, b, c = col
        stdout.echo_rendered(
            pt.Fragment(
                c,
                pt.Style(
                    # fg=pt.rgb_to_hex(pt.RGB(max(0, r - 128), max(0, g - 128), max(0, b - 128))),
                    fg=pt.rgb_to_hex(pt.RGB(255 - r, 255 - g, 255 - b)),
                    bg=pt.rgb_to_hex(pt.RGB(r, g, b)),
                ),
            ),
            nl=False,
        )
    stdout.echo(pt.SeqIndex.BOLD_DIM_OFF)
    stdout.echo()
